PathProviderMasterWeb class

A web implementation of the PathProviderMasterPlatform of the PathProviderMaster plugin.

Web platform uses browser storage APIs:

  • IndexedDB for temporary storage
  • localStorage for persistent storage
  • File System Access API (when available)

Note: Web browsers have storage limitations and different security models. Most directories return virtual paths that map to browser storage.

Inheritance

Constructors

PathProviderMasterWeb()
Constructs a PathProviderMasterWeb

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getApplicationDocumentsDirectory() → Future<String?>
override
getApplicationSupportDirectory() → Future<String?>
override
getDownloadsDirectory() → Future<String?>
override
getExternalCacheDirectories() → Future<List<String>?>
override
getExternalStorageDirectories() → Future<List<String>?>
override
getExternalStorageDirectory() → Future<String?>
override
getLibraryDirectory() → Future<String?>
override
getPublicDCIMDirectory() → Future<String?>
override
getPublicDocumentsDirectory() → Future<String?>
override
getPublicDownloadsDirectory() → Future<String?>
override
getPublicMusicDirectory() → Future<String?>
override
getPublicPicturesDirectory() → Future<String?>
override
getPublicVideosDirectory() → Future<String?>
override
getTemporaryDirectory() → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void